@@ -1,5 +1,23 @@
 var NAVTREEINDEX16 =
 {
+"page_library.html#autotoc_md63":[5,9,6],
+"page_library.html#autotoc_md64":[5,9,7],
+"page_man_pipewire_1.html":[5,14,0],
+"page_man_pipewire_conf_5.html":[5,14,2],
+"page_man_pipewire_pulse_1.html":[5,14,1],
+"page_man_pw_cat_1.html":[5,14,3],
+"page_man_pw_cli_1.html":[5,14,4],
+"page_man_pw_config_1.html":[5,14,5],
+"page_man_pw_dot_1.html":[5,14,6],
+"page_man_pw_jack_1.html":[5,14,13],
+"page_man_pw_link_1.html":[5,14,7],
+"page_man_pw_metadata_1.html":[5,14,8],
+"page_man_pw_mididump_1.html":[5,14,9],
+"page_man_pw_mon_1.html":[5,14,10],
+"page_man_pw_profiler_1.html":[5,14,11],
+"page_man_pw_top_1.html":[5,14,12],
+"page_midi.html":[5,7],
+"page_midi.html#autotoc_md20":[5,7,0],
 "page_midi.html#autotoc_md21":[5,7,0,0],
 "page_midi.html#autotoc_md22":[5,7,0,1],
 "page_midi.html#autotoc_md23":[5,7,0,2],
@@ -231,23 +249,5 @@ var NAVTREEINDEX16 =
 "page_scheduling.html#autotoc_md115":[5,11,3,0],
 "page_session_manager.html":[5,15],
 "page_session_manager.html#autotoc_md65":[5,15,0],
-"page_session_manager.html#autotoc_md66":[5,15,1],
-"page_session_manager.html#autotoc_md67":[5,15,2],
-"page_spa.html":[9],
-"page_spa.html#autotoc_md223":[9,0],
-"page_spa.html#autotoc_md224":[9,1],
-"page_spa.html#autotoc_md225":[9,2],
-"page_spa.html#autotoc_md226":[9,3],
-"page_spa_buffer.html":[9,7],
-"page_spa_design.html":[9,4],
-"page_spa_design.html#autotoc_md239":[9,4,0],
-"page_spa_design.html#autotoc_md240":[9,4,0,0],
-"page_spa_design.html#autotoc_md241":[9,4,0,1],
-"page_spa_design.html#autotoc_md242":[9,4,0,2],
-"page_spa_plugins.html":[9,5],
-"page_spa_plugins.html#autotoc_md227":[9,5,0],
-"page_spa_plugins.html#autotoc_md228":[9,5,1],
-"page_spa_plugins.html#autotoc_md229":[9,5,2],
-"page_spa_plugins.html#autotoc_md230":[9,5,3],
-"page_spa_plugins.html#autotoc_md231":[9,5,4]
+"page_session_manager.html#autotoc_md66":[5,15,1]
 };
